diff --git a/src/kademlia/net/KademliaUDPListener.cpp b/src/kademlia/net/KademliaUDPListener.cpp
index 084eef5..af60f17 100644
--- a/src/kademlia/net/KademliaUDPListener.cpp
+++ b/src/kademlia/net/KademliaUDPListener.cpp
@@ -524,7 +524,9 @@ void CKademliaUDPListener::Process2HelloRequest(const uint8_t *packetData, uint3
 	uint8_t contactVersion = 0;
 	CUInt128 contactID;
 	bool addedOrUpdated = AddContact2(packetData, lenPacket, ip, port, &contactVersion, senderKey, validReceiverKey, true, true, NULL, &contactID); // might change (udp)port, validReceiverKey
-	wxASSERT(contactVersion >= 2);
+	if (contactVersion < 2) {
+		throw wxString(CFormat(wxT("***NOTE: Received invalid Kademlia2 version (%u) in %s")) % contactVersion % wxString::FromAscii(__FUNCTION__));
+	}
 #ifdef __DEBUG__
 	if (dbgOldUDPPort != port) {
 		AddDebugLogLineN(logClientKadUDP, CFormat(wxT("KadContact %s uses his internal (%u) instead external (%u) UDP Port")) % KadIPToString(ip) % port % dbgOldUDPPort);
@@ -1650,7 +1652,6 @@ void CKademliaUDPListener::SendLegacyChallenge(uint32_t ip, uint16_t port, const
 	CUInt128 challenge(GetRandomUint128());
 	if (challenge == 0) {
 		// hey there is a 2^128 chance that this happens ;)
-		wxFAIL;
 		challenge = 1;
 	}
 	// Put the target we want into the packet. This is our challenge
diff --git a/src/kademlia/routing/RoutingZone.cpp b/src/kademlia/routing/RoutingZone.cpp
index 7fedf53..3887090 100644
--- a/src/kademlia/routing/RoutingZone.cpp
+++ b/src/kademlia/routing/RoutingZone.cpp
@@ -270,7 +270,6 @@ void CRoutingZone::ReadBootstrapNodesDat(CFileDataIO& file)
 							}
 						}
 						if (!inserted) {
-							wxASSERT(CKademlia::s_bootstrapList.size() < 50);
 							CKademlia::s_bootstrapList.push_back(contact);
 						} else if (CKademlia::s_bootstrapList.size() > 50) {
 							delete CKademlia::s_bootstrapList.back();
@@ -811,6 +810,7 @@ void CRoutingZone::OnSmallTimer()
 			CKademlia::GetUDPListener()->SendMyDetails(KADEMLIA2_HELLO_REQ, c->GetIPAddress(), c->GetUDPPort(), c->GetVersion(), 0, NULL, false);
 			wxASSERT(c->GetUDPKey() == CKadUDPKey(0));
 		} else {
+			AddDebugLogLineN(logKadRouting, CFormat(wxT("Ignoring Kad contact %s version %d.")) % KadIPToString(c->GetIPAddress()) % c->GetVersion());
 			//wxFAIL;	// thanks, I'm having enough problems without any Kad asserts
 		}
 	}
